# Server Details

This folder is used to store all of the server details that have been launched by this architect, such that there is a location to find the details and cleanup if something goes wrong. 

If you want to clean up used subdomains (not including fallback though), please use `mephisto/abstractions/architects/ec2/cleanup_ec2_server_by_name.py`.